@@ -8,8 +8,14 @@
 
 #include <QObject>
 
+#include <kdnssd_version.h>
+#if KDNSSD_VERSION >= QT_VERSION_CHECK(5, 84, 0)
+#include <KDNSSD/RemoteService>
+#include <KDNSSD/ServiceBrowser>
+#else
 #include <DNSSD/RemoteService>
 #include <DNSSD/ServiceBrowser>
+#endif
 
 #include "discovery.h"
 
@@ -33,7 +39,7 @@ public:
     void start() override;
     bool isFinished() const override;
 
-signals:
+Q_SIGNALS:
     void newDiscovery(Discovery::Ptr discovery) override;
     void finished() override;
 
